import { EventData, Observable } from '@nativescript/core';
import { DfuServiceController } from './serviceController';
export declare enum DfuState {
    CONNECTING = 0,
    DFU_PROCESS_STARTING = 1,
    ENABLING_DFU_MODE = 2,
    FIRMWARE_VALIDATING = 3,
    DEVICE_DISCONNECTING = 4,
    DFU_COMPLETED = 5,
    DFU_ABORTED = 6,
    DFU_FAILED = 7
}
export declare abstract class DFUInitiatorCommon extends Observable {
    static readonly dfuStateChangedEvent = "DFUStateChanged";
    static readonly dfuProgressEvent = "DFUProgress";
    protected readonly mPeripheralUUID: string;
    constructor(peripheralUUID: string);
    get peripheralUUID(): string;
    abstract setDeviceName(name: string): DFUInitiatorCommon;
    abstract setKeepBond(val: boolean): DFUInitiatorCommon;
    abstract setForceDfu(val: boolean): DFUInitiatorCommon;
    abstract setForceScanningForNewAddressInLegacyDfu(val: boolean): DFUInitiatorCommon;
    abstract setUnsafeExperimentalButtonlessServiceInSecureDfuEnabled(val: boolean): DFUInitiatorCommon;
    abstract setPacketReceiptNotificationParameter(val: number): DFUInitiatorCommon;
    abstract disableResume(): DFUInitiatorCommon;
    abstract start(filePath: string): DfuServiceController;
    protected _registerProgressListener(): void;
    protected _removeProgressListener(): void;
    _notifyDfuStateChanged(state: DfuState, reason?: string): void;
    addEventListener(eventName: string, callback: (data: EventData) => void, thisArg?: any, once?: boolean): void;
    removeEventListener(eventName: string, callback?: (data: EventData) => void, thisArg?: any): void;
    private get hasDfuListeners();
}
