import { Observable } from '@nativescript/core';
export var DfuState;
(function (DfuState) {
    DfuState[DfuState["CONNECTING"] = 0] = "CONNECTING";
    DfuState[DfuState["DFU_PROCESS_STARTING"] = 1] = "DFU_PROCESS_STARTING";
    DfuState[DfuState["ENABLING_DFU_MODE"] = 2] = "ENABLING_DFU_MODE";
    DfuState[DfuState["FIRMWARE_VALIDATING"] = 3] = "FIRMWARE_VALIDATING";
    DfuState[DfuState["DEVICE_DISCONNECTING"] = 4] = "DEVICE_DISCONNECTING";
    DfuState[DfuState["DFU_COMPLETED"] = 5] = "DFU_COMPLETED";
    DfuState[DfuState["DFU_ABORTED"] = 6] = "DFU_ABORTED";
    DfuState[DfuState["DFU_FAILED"] = 7] = "DFU_FAILED";
})(DfuState || (DfuState = {}));
export class DFUInitiatorCommon extends Observable {
    constructor(peripheralUUID) {
        super();
        this.mPeripheralUUID = peripheralUUID;
    }
    get peripheralUUID() {
        return this.mPeripheralUUID;
    }
    _registerProgressListener() { }
    _removeProgressListener() { }
    _notifyDfuStateChanged(state, reason) {
        this.notify({
            eventName: DFUInitiatorCommon.dfuStateChangedEvent,
            object: this,
            state: state,
            reason,
        });
    }
    addEventListener(eventName, callback, thisArg, once) {
        const hasAlreadyAddedListeners = this.hasDfuListeners;
        super.addEventListener(eventName, callback, thisArg, once);
        if (!hasAlreadyAddedListeners && this.hasDfuListeners) {
            this._registerProgressListener();
        }
    }
    removeEventListener(eventName, callback, thisArg) {
        const hasOldListeners = this.hasDfuListeners;
        super.removeEventListener(eventName, callback, thisArg);
        if (hasOldListeners && !this.hasDfuListeners) {
            this._removeProgressListener();
        }
    }
    get hasDfuListeners() {
        return this.hasListeners(DFUInitiatorCommon.dfuStateChangedEvent) || this.hasListeners(DFUInitiatorCommon.dfuProgressEvent);
    }
}
DFUInitiatorCommon.dfuStateChangedEvent = 'DFUStateChanged';
DFUInitiatorCommon.dfuProgressEvent = 'DFUProgress';
//# sourceMappingURL=common.js.map